@@ -180,11 +180,11 @@ int nebmodule_init( int flags, char *args, nebmodule *handle ) {
 static void register_neb_callbacks(void) {
 
     /* only if we have hostgroups defined or general hosts enabled */
-    if ( mod_gm_opt->do_hostchecks == GM_ENABLED && ( mod_gm_opt->hostgroups_num > 0 || mod_gm_opt->hosts == GM_ENABLED ))
+    if ( mod_gm_opt->do_hostchecks == GM_ENABLED && ( mod_gm_opt->hostgroups_num > 0 || mod_gm_opt->hosts == GM_ENABLED || mod_gm_opt->queue_cust_var ))
         neb_register_callback( NEBCALLBACK_HOST_CHECK_DATA,    gearman_module_handle, 0, handle_host_check );
 
     /* only if we have groups defined or general services enabled */
-    if ( mod_gm_opt->servicegroups_num > 0 || mod_gm_opt->hostgroups_num > 0 || mod_gm_opt->services == GM_ENABLED )
+    if ( mod_gm_opt->servicegroups_num > 0 || mod_gm_opt->hostgroups_num > 0 || mod_gm_opt->services == GM_ENABLED || mod_gm_opt->queue_cust_var )
         neb_register_callback( NEBCALLBACK_SERVICE_CHECK_DATA, gearman_module_handle, 0, handle_svc_check );
 
     if ( mod_gm_opt->events == GM_ENABLED )
@@ -246,6 +246,11 @@ int nebmodule_deinit( int flags, int reason ) {
     /* cleanup */
     free_client(&client);
 
+    /* close old logfile */
+    if(mod_gm_opt->logfile_fp != NULL) {
+        fclose(mod_gm_opt->logfile_fp);
+    }
+
     mod_gm_free_opt(mod_gm_opt);
 
     return NEB_OK;
@@ -438,6 +443,13 @@ static int handle_eventhandler( int event_type, void *data ) {
         return NEB_OK;
     }
 
+    if(mod_gm_opt->route_eventhandler_like_checks != GM_ENABLED || !strcmp( target_queue, "host" ) || !strcmp( target_queue, "service" )) {
+        target_queue[0] = '\x0';
+        snprintf( target_queue, GM_BUFFERSIZE-1, "eventhandler" );
+    }
+
+    gm_log( GM_LOG_DEBUG, "eventhandler for queue %s\n", target_queue );
+
     temp_buffer[0]='\x0';
     snprintf( temp_buffer,GM_BUFFERSIZE-1,
                 "type=eventhandler\nstart_time=%i.0\ncore_time=%i.%i\ncommand_line=%s\n\n\n",
@@ -449,7 +461,7 @@ static int handle_eventhandler( int event_type, void *data ) {
 
     if(add_job_to_queue( &client,
                          mod_gm_opt->server_list,
-                         "eventhandler",
+                         target_queue,
                          NULL,
                          temp_buffer,
                          GM_JOB_PRIO_NORMAL,
@@ -529,36 +541,14 @@ static int handle_host_check( int event_type, void *data ) {
     check_options = hst->check_options;
     hst->check_options = CHECK_OPTION_NONE;
 
+    /* unset the freshening flag, otherwise only the first freshness check would be run */
+    hst->is_being_freshened=FALSE;
+
     /* adjust host check attempt */
     adjust_host_check_attempt_3x(hst,TRUE);
 
     temp_buffer[0]='\x0';
 
-    /* orphanded check? */
-    if(mod_gm_opt->orphan_host_checks == GM_ENABLED && check_options & CHECK_OPTION_ORPHAN_CHECK) {
-        gm_log( GM_LOG_DEBUG, "host check for %s orphanded\n", hst->name );
-        if ( ( chk_result = ( check_result * )malloc( sizeof *chk_result ) ) == 0 )
-            return NEBERROR_CALLBACKCANCEL;
-        snprintf( temp_buffer,GM_BUFFERSIZE-1,"(host check orphaned, is the mod-gearman worker on queue '%s' running?)\n", target_queue);
-        init_check_result(chk_result);
-        chk_result->host_name           = strdup( hst->name );
-        chk_result->scheduled_check     = TRUE;
-        chk_result->reschedule_check    = TRUE;
-        chk_result->output_file         = 0;
-        chk_result->output_file_fd      = -1;
-        chk_result->output              = strdup(temp_buffer);
-        chk_result->return_code         = 2;
-        chk_result->check_options       = CHECK_OPTION_NONE;
-        chk_result->object_check_type   = HOST_CHECK;
-        chk_result->check_type          = HOST_CHECK_ACTIVE;
-        chk_result->start_time.tv_sec   = (unsigned long)time(NULL);
-        chk_result->finish_time.tv_sec  = (unsigned long)time(NULL);
-        chk_result->latency             = 0;
-        mod_gm_add_result_to_list( chk_result );
-        chk_result = NULL;
-        return NEBERROR_CALLBACKCANCEL;
-    }
-
     /* grab the host macro variables */
     clear_volatile_macros();
     grab_host_macros(hst);
@@ -606,7 +596,7 @@ static int handle_host_check( int event_type, void *data ) {
     if(add_job_to_queue( &client,
                          mod_gm_opt->server_list,
                          target_queue,
-                         hst->name,
+                        (mod_gm_opt->use_uniq_jobs == GM_ENABLED ? hst->name : NULL),
                          temp_buffer,
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
@@ -632,6 +622,30 @@ static int handle_host_check( int event_type, void *data ) {
     my_free(raw_command);
     my_free(processed_command);
 
+    /* orphanded check - submit fake result to mark host as orphaned */
+    if(mod_gm_opt->orphan_host_checks == GM_ENABLED && check_options & CHECK_OPTION_ORPHAN_CHECK) {
+        gm_log( GM_LOG_DEBUG, "host check for %s orphanded\n", hst->name );
+        if ( ( chk_result = ( check_result * )malloc( sizeof *chk_result ) ) == 0 )
+            return NEBERROR_CALLBACKCANCEL;
+        snprintf( temp_buffer,GM_BUFFERSIZE-1,"(host check orphaned, is the mod-gearman worker on queue '%s' running?)\n", target_queue);
+        init_check_result(chk_result);
+        chk_result->host_name           = strdup( hst->name );
+        chk_result->scheduled_check     = TRUE;
+        chk_result->reschedule_check    = TRUE;
+        chk_result->output_file         = 0;
+        chk_result->output_file_fd      = -1;
+        chk_result->output              = strdup(temp_buffer);
+        chk_result->return_code         = 2;
+        chk_result->check_options       = CHECK_OPTION_NONE;
+        chk_result->object_check_type   = HOST_CHECK;
+        chk_result->check_type          = HOST_CHECK_ACTIVE;
+        chk_result->start_time.tv_sec   = (unsigned long)time(NULL);
+        chk_result->finish_time.tv_sec  = (unsigned long)time(NULL);
+        chk_result->latency             = 0;
+        mod_gm_add_result_to_list( chk_result );
+        chk_result = NULL;
+    }
+
     /* tell nagios to not execute */
     gm_log( GM_LOG_TRACE, "handle_host_check() finished successfully -> %d\n", NEBERROR_CALLBACKOVERRIDE );
     return NEBERROR_CALLBACKOVERRIDE;
@@ -692,32 +706,6 @@ static int handle_svc_check( int event_type, void *data ) {
 
     temp_buffer[0]='\x0';
 
-    /* orphanded check? */
-    if(mod_gm_opt->orphan_service_checks == GM_ENABLED && svc->check_options & CHECK_OPTION_ORPHAN_CHECK) {
-        gm_log( GM_LOG_DEBUG, "service check for %s - %s orphanded\n", svc->host_name, svc->description );
-        if ( ( chk_result = ( check_result * )malloc( sizeof *chk_result ) ) == 0 )
-            return NEBERROR_CALLBACKCANCEL;
-        snprintf( temp_buffer,GM_BUFFERSIZE-1,"(service check orphaned, is the mod-gearman worker on queue '%s' running?)\n", target_queue);
-        init_check_result(chk_result);
-        chk_result->host_name           = strdup( svc->host_name );
-        chk_result->service_description = strdup( svc->description );
-        chk_result->scheduled_check     = TRUE;
-        chk_result->reschedule_check    = TRUE;
-        chk_result->output_file         = 0;
-        chk_result->output_file_fd      = -1;
-        chk_result->output              = strdup(temp_buffer);
-        chk_result->return_code         = 2;
-        chk_result->check_options       = CHECK_OPTION_NONE;
-        chk_result->object_check_type   = SERVICE_CHECK;
-        chk_result->check_type          = SERVICE_CHECK_ACTIVE;
-        chk_result->start_time.tv_sec   = (unsigned long)time(NULL);
-        chk_result->finish_time.tv_sec  = (unsigned long)time(NULL);
-        chk_result->latency             = 0;
-        mod_gm_add_result_to_list( chk_result );
-        chk_result = NULL;
-        return NEBERROR_CALLBACKCANCEL;
-    }
-
     /* as we have to intercept service checks so early
      * (we cannot cancel checks otherwise)
      * we have to do some service check logic here
@@ -726,6 +714,9 @@ static int handle_svc_check( int event_type, void *data ) {
     /* clear check options - we don't want old check options retained */
     svc->check_options=CHECK_OPTION_NONE;
 
+    /* unset the freshening flag, otherwise only the first freshness check would be run */
+    svc->is_being_freshened=FALSE;
+
     /* grab the host and service macro variables */
     clear_volatile_macros();
     grab_host_macros(hst);
@@ -783,7 +774,7 @@ static int handle_svc_check( int event_type, void *data ) {
     if(add_job_to_queue( &client,
                          mod_gm_opt->server_list,
                          target_queue,
-                         uniq,
+                        (mod_gm_opt->use_uniq_jobs == GM_ENABLED ? uniq : NULL),
                          temp_buffer,
                          prio,
                          GM_DEFAULT_JOB_RETRIES,
@@ -810,7 +801,34 @@ static int handle_svc_check( int event_type, void *data ) {
     my_free(raw_command);
     my_free(processed_command);
 
+    /* orphanded check - submit fake result to mark service as orphaned */
+    if(mod_gm_opt->orphan_service_checks == GM_ENABLED && svc->check_options & CHECK_OPTION_ORPHAN_CHECK) {
+        gm_log( GM_LOG_DEBUG, "service check for %s - %s orphanded\n", svc->host_name, svc->description );
+        if ( ( chk_result = ( check_result * )malloc( sizeof *chk_result ) ) == 0 )
+            return NEBERROR_CALLBACKCANCEL;
+        snprintf( temp_buffer,GM_BUFFERSIZE-1,"(service check orphaned, is the mod-gearman worker on queue '%s' running?)\n", target_queue);
+        init_check_result(chk_result);
+        chk_result->host_name           = strdup( svc->host_name );
+        chk_result->service_description = strdup( svc->description );
+        chk_result->scheduled_check     = TRUE;
+        chk_result->reschedule_check    = TRUE;
+        chk_result->output_file         = 0;
+        chk_result->output_file_fd      = -1;
+        chk_result->output              = strdup(temp_buffer);
+        chk_result->return_code         = 2;
+        chk_result->check_options       = CHECK_OPTION_NONE;
+        chk_result->object_check_type   = SERVICE_CHECK;
+        chk_result->check_type          = SERVICE_CHECK_ACTIVE;
+        chk_result->start_time.tv_sec   = (unsigned long)time(NULL);
+        chk_result->finish_time.tv_sec  = (unsigned long)time(NULL);
+        chk_result->latency             = 0;
+        mod_gm_add_result_to_list( chk_result );
+        chk_result = NULL;
+    }
+
     /* tell nagios to not execute */
+    gm_log( GM_LOG_TRACE, "handle_svc_check() finished successfully -> %d\n", NEBERROR_CALLBACKOVERRIDE );
+
     return NEBERROR_CALLBACKOVERRIDE;
 }
 
