@@ -27,7 +27,7 @@
 #include "worker_client.h"
 #include "utils.h"
 #include "check_utils.h"
-#include "gearman.h"
+#include "gearman_utils.h"
 #ifdef EMBEDDEDPERL
 #include "epn_utils.h"
 #endif
@@ -143,7 +143,6 @@ void worker_loop() {
 /* get a job */
 void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_return_t *ret_ptr ) {
     sigset_t block_mask;
-    sigset_t old_mask;
     int wsize, valid_lines;
     char workload[GM_BUFFERSIZE];
     char * decrypted_data;
@@ -174,7 +173,7 @@ void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_
     /* ignore sigterms while running job */
     sigemptyset(&block_mask);
     sigaddset(&block_mask, SIGTERM);
-    sigprocmask(SIG_BLOCK, &block_mask, &old_mask);
+    sigprocmask(SIG_BLOCK, &block_mask, NULL);
 
     /* get the data */
     current_gearman_job = job;
@@ -263,7 +262,7 @@ void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_
 #endif
 
     if(valid_lines == 0) {
-        gm_log( GM_LOG_ERROR, "discarded invalid job, check your encryption settings\n" );
+        gm_log( GM_LOG_ERROR, "discarded invalid job (%s), check your encryption settings\n", gearman_job_handle( job ) );
     } else {
         do_exec_job();
     }
@@ -271,7 +270,7 @@ void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_
     current_gearman_job = NULL;
 
     /* start listening to SIGTERMs */
-    sigprocmask(SIG_SETMASK, &old_mask, NULL);
+    sigprocmask(SIG_UNBLOCK, &block_mask, NULL);
 
     free(decrypted_orig);
     free(decrypted_data_c);
@@ -444,7 +443,7 @@ void set_state(int status) {
     if(status == GM_JOB_START)
         shm[shm_index] = current_pid;
     if(status == GM_JOB_END) {
-        shm[0]++; /* increase jobs done */
+        shm[SHM_JOBS_DONE]++; /* increase jobs done */
 
         /* status slot changed to -1 -> exit */
         if( shm[shm_index] == -1 ) {
@@ -478,8 +477,14 @@ void clean_worker_exit(int sig) {
 
     /* clear gearmans job, otherwise it would be retried and retried */
     if(current_gearman_job != NULL) {
-        send_failed_result(current_job, sig);
-        gearman_job_send_complete(current_gearman_job, NULL, 0);
+        if(sig == SIGINT) {
+            /* if worker stopped with sigint, let the job retry */
+        } else {
+            send_failed_result(current_job, sig);
+            gearman_job_send_complete(current_gearman_job, NULL, 0);
+        }
+        /* make sure no processes are left over */
+        kill_child_checks();
     }
 
     gm_log( GM_LOG_TRACE, "cleaning worker\n");
@@ -490,7 +495,7 @@ void clean_worker_exit(int sig) {
     mod_gm_free_opt(mod_gm_opt);
 
 #ifdef EMBEDDEDPERL
-    deinit_embedded_perl();
+    deinit_embedded_perl(0);
 #endif
 
     if(worker_run_mode == GM_WORKER_STANDALONE)
@@ -502,6 +507,7 @@ void clean_worker_exit(int sig) {
         gm_log( GM_LOG_TRACE, "worker finished: %d\n", getpid() );
         _exit( EXIT_FAILURE );
     }
+    /* clean our pid from worker list */
     if( shm[shm_index] == current_pid || shm[shm_index] == -current_pid ) {
         shm[shm_index] = -1;
     }
@@ -547,10 +553,10 @@ void *return_status( gearman_job_st *job, void *context, size_t *result_size, ge
         return NULL;
     }
 
-    snprintf(result, GM_BUFFERSIZE, "%s has %i worker and is working on %i jobs. Version: %s|worker=%i;;;%i;%i jobs=%ic", hostname, shm[1], shm[2], GM_VERSION, shm[1], mod_gm_opt->min_worker, mod_gm_opt->max_worker, shm[0] );
+    snprintf(result, GM_BUFFERSIZE, "%s has %i worker and is working on %i jobs. Version: %s|worker=%i;;;%i;%i jobs=%ic", hostname, shm[SHM_WORKER_TOTAL], shm[SHM_WORKER_RUNNING], GM_VERSION, shm[SHM_WORKER_TOTAL], mod_gm_opt->min_worker, mod_gm_opt->max_worker, shm[SHM_JOBS_DONE] );
 
     /* and increase job counter */
-    shm[0]++;
+    shm[SHM_JOBS_DONE]++;
 
     /* detach from shared memory */
     if(shmdt(shm) < 0)
